@@ -37,7 +37,7 @@
 /* For version detection */
 #define OPENIPMI_VERSION_MAJOR 1
 #define OPENIPMI_VERSION_MINOR 3
-#define OPENIPMI_VERSION_RELEASE 13
+#define OPENIPMI_VERSION_RELEASE 16
 #define OPENIPMI_VERSION_EXTRA 
 #define OPENIPMI_STRINGX(x) #x
 #define OPENIPMI_XSTRING(x) OPENIPMI_STRINGX(x)
@@ -855,6 +855,12 @@ char *ipmi_hot_swap_state_name(enum ipmi_hot_swap_states state);
 /* Does the entity implement a hot-swap state machine? */
 int ipmi_entity_hot_swappable(ipmi_entity_t *ent);
 
+/* If this returns false but the entity is hot-swappable, then it
+   supports managed hot swap.  If not, is supports only the
+   not-present and active hot-swap states and the changes cannot be
+   managed. */
+int ipmi_entity_supports_managed_hot_swap(ipmi_entity_t *ent);
+
 /* Register to receive the hot-swap state when it changes.  the
    handler returns an integer.  It should return IPMI_EVENT_HANDLED if
    it handled the event, or IPMI_EVENT_NOT_HANDLED if it didn't handle
@@ -1515,6 +1521,7 @@ int ipmi_control_is_settable(ipmi_control_t *control);
 int ipmi_control_is_readable(ipmi_control_t *control);
 ipmi_entity_t *ipmi_control_get_entity(ipmi_control_t *control);
 char *ipmi_control_get_type_string(ipmi_control_t *control);
+int ipmi_control_get_ignore_if_no_entity(ipmi_control_t *control);
 
 /* Get the number of values the control supports. */
 int ipmi_control_get_num_vals(ipmi_control_t *control);
