@@ -230,7 +230,6 @@ atca_alloc_control(ipmi_mc_t                 *mc,
     ipmi_control_set_oem_info(*control, data, data_cleanup);
     ipmi_control_set_type(*control, control_type);
     ipmi_control_set_id(*control, id, IPMI_ASCII_STR, strlen(id));
-    ipmi_control_set_ignore_if_no_entity(*control, 1);
 
     /* Assume we can read and set the value. */
     if ((set_val) || (set_light_val) || (set_id_val))
@@ -889,6 +888,7 @@ setup_fru_hot_swap(atca_fru_t *finfo, ipmi_sensor_t *sensor)
     finfo->hs_sensor_id = ipmi_sensor_convert_to_id(sensor);
 
     ipmi_entity_set_hot_swappable(finfo->entity, 1);
+    ipmi_entity_set_supports_managed_hot_swap(finfo->entity, 1);
     ipmi_entity_set_hot_swap_control(finfo->entity, &atca_hot_swap_handlers);
 
     rv = ipmi_sensor_add_discrete_event_handler(sensor, hot_swap_state_changed,
@@ -2235,6 +2235,7 @@ atca_sensor_update_handler(enum ipmi_update_e op,
 					       &event,
 					       &handled);
 	    ipmi_entity_set_hot_swappable(entity, 0);
+	    ipmi_entity_set_supports_managed_hot_swap(entity, 0);
 	}
 	break;
 
@@ -3236,46 +3237,35 @@ atca_entity_fixup(ipmi_mc_t *mc, unsigned char *id, unsigned char *instance)
 	if ((addr == 0x62) || (addr == 0x64)) {
 	    /* Power unit. */
 	    *id = 10;
-	    inst = 0x60;
 	} else if (addr == 0x42) {
 	    /* Fan tray */
 	    *id = 30;
-	    inst = 0x60;
 	} else {
 	    *id = 0xa0;
-	    inst = 0x60;
 	}
 	break;
 
     case 6:
 	*id = 0xf0;
-	inst = 0x60;
-	break;
-
-    case 3:
-	if (inst < 0x60)
-	    inst = 0x60;
 	break;
 
     case 23:
 	if ((inst == 1) || (inst == 2)) {
 	    *id = 0xf2;
-	    inst = 0x60;
+	    inst += 0x60 - 1;
 	} else if (inst == 3) {
 	    *id = 0xf1;
 	    inst = 0x60;
 	}
 	break;
 
-    case 34:
-	inst = 0x60;
-	break;
-
     case 0xa0:
 	/* These instances should all be set to 0x60 */
 	inst = 0x60;
 	break;
     }
+    if (inst < 0x60)
+	inst += 0x60;
 
     *instance = (*instance & 0x80) | (inst & 0x7f);
 }
